@@ -1,6 +1,6 @@
 import pytest
 
-import pg8000.dbapi
+from pg8000.dbapi import DatabaseError, InterfaceError, connect
 
 
 # This requires a line in pg_hba.conf that requires md5 for the database
@@ -11,8 +11,9 @@ def testMd5(db_kwargs):
     db_kwargs["database"] = "pg8000_md5"
 
     # Should only raise an exception saying db doesn't exist
-    with pytest.raises(pg8000.dbapi.DatabaseError, match="3D000"):
-        pg8000.dbapi.connect(**db_kwargs)
+    with pytest.raises(DatabaseError, match="3D000"):
+        with connect(**db_kwargs):
+            pass
 
 
 # This requires a line in pg_hba.conf that requires gss for the database
@@ -24,10 +25,11 @@ def testGss(db_kwargs):
 
     # Should raise an exception saying gss isn't supported
     with pytest.raises(
-        pg8000.dbapi.InterfaceError,
+        InterfaceError,
         match="Authentication method 7 not supported by pg8000.",
     ):
-        pg8000.dbapi.connect(**db_kwargs)
+        with connect(**db_kwargs):
+            pass
 
 
 # This requires a line in pg_hba.conf that requires 'password' for the
@@ -38,8 +40,9 @@ def testPassword(db_kwargs):
     db_kwargs["database"] = "pg8000_password"
 
     # Should only raise an exception saying db doesn't exist
-    with pytest.raises(pg8000.dbapi.DatabaseError, match="3D000"):
-        pg8000.dbapi.connect(**db_kwargs)
+    with pytest.raises(DatabaseError, match="3D000"):
+        with connect(**db_kwargs):
+            pass
 
 
 # This requires a line in pg_hba.conf that requires scram-sha-256 for the
@@ -50,5 +53,6 @@ def test_scram_sha_256(db_kwargs):
     db_kwargs["database"] = "pg8000_scram_sha_256"
 
     # Should only raise an exception saying db doesn't exist
-    with pytest.raises(pg8000.dbapi.DatabaseError, match="3D000"):
-        pg8000.dbapi.connect(**db_kwargs)
+    with pytest.raises(DatabaseError, match="3D000"):
+        with connect(**db_kwargs) as con:
+            con.close()
